==> devix-2.0.0.tar.gz: devix-2.0.0/CHANGELOG.md <==
# Changelog

All notable changes to Devix will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [2.0.0] - 2024-09-09

### Added
- **Complete modular architecture refactor** from legacy AutoDev to modern Devix
- **5 specialized analyzers**:
  - ProjectScanner (project structure, file stats, tree visualization)
  - SecurityAnalyzer (vulnerability detection with bandit and safety)
  - QualityAnalyzer (code quality with pylint, flake8, mypy)
  - TestAnalyzer (test coverage and quality analysis)
  - PerformanceAnalyzer (performance bottleneck detection)
- **Enhanced reporting system**:
  - Dual-format reports (Markdown and Text)
  - Project structure visualization with ASCII tree
  - Ignore markers (🚫) for filtered files
  - Comprehensive file statistics and metrics
  - Actionable recommendations and priority analysis
- **Modern CLI interface**:
  - `devix analyze` - Run comprehensive analysis
  - `devix config` - Manage configuration
  - `devix info` - Show package and analyzer information
- **`.devixignore` integration**:
  - GitIgnore-style pattern matching
  - Visual indicators in reports for ignored files
  - Configurable ignore patterns
- **Advanced Makefile with script reorganization**:
  - Organized scripts in `devix/scripts/` directory
  - UV package manager support with pip fallback
  - Docker containerization support
  - Watch mode for continuous analysis
  - Complete CI/CD pipeline simulation
- **PyPI publication pipeline**:
  - Comprehensive `pyproject.toml` configuration
  - Build system with hatchling
  - Multiple distribution formats (wheel, sdist)
  - Development, testing, and documentation dependencies

### Changed
- **Complete codebase restructure**: `devix/{core,analysis,reporting,cli,config}`
- **Parallel analyzer execution** for improved performance
- **Enhanced error handling** and logging throughout the system
- **Modernized configuration** using YAML and pyproject.toml standards
- **Improved package discovery** and module resolution

### Fixed
- **Makefile UV dependency** - added comprehensive pip/twine fallback
- **Project tree visualization** - collapsed folders with all ignored contents
- **Path resolution issues** in different execution contexts
- **Import resolution** for modular package structure
- **CLI command registration** and entry points

### Technical Details
- **Python compatibility**: 3.8+ with comprehensive testing
- **Zero breaking changes** for basic analysis workflows
- **Extensible architecture** for custom analyzers and formatters
- **Rich dependency management** with optional feature groups
- **Production-ready** with comprehensive error handling and logging

### Migration from AutoDev
- Legacy AutoDev workflows remain compatible
- Enhanced reports provide significantly more detail
- Modular architecture allows selective analyzer usage
- Configuration migrates automatically from legacy formats

### Performance Improvements
- **Parallel execution** of multiple analyzers
- **Efficient file filtering** with compiled ignore patterns
- **Optimized reporting** with lazy evaluation
- **Memory management** improvements for large codebases

## [1.x.x] - Legacy AutoDev Versions

Previous versions were part of the AutoDev system. See project history for details of legacy functionality that has been enhanced and modernized in Devix 2.0.0.

---

### Development Status

- **Status**: Production Ready
- **Stability**: Beta (API may change in minor versions)
- **Maintenance**: Actively maintained
- **Python Support**: 3.8, 3.9, 3.10, 3.11, 3.12

### Contributing

Please see [CONTRIBUTING.md](CONTRIBUTING.md) for guidelines on contributing to Devix.

### License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.

==> devix-2.1.4.tar.gz: devix-2.1.4/CHANGELOG.md <==
# Changelog

All notable changes to Devix will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [2.0.1] - 2024-09-09

### Fixed
- **Makefile UV detection**: Fixed robust fallback mechanism when UV is not available
- **Publishing workflow**: Improved error handling and fallback to twine
- **Version management**: Enhanced version bumping and publishing pipeline

### Technical Improvements
- **Build system**: More reliable dependency detection and installation
- **Error handling**: Better error messages for missing dependencies
- **Publishing**: Streamlined PyPI publication process


## [2.0.0] - 2024-09-09

### Added
- **Complete modular architecture refactor** from legacy AutoDev to modern Devix
- **5 specialized analyzers**:
  - ProjectScanner (project structure, file stats, tree visualization)
  - SecurityAnalyzer (vulnerability detection with bandit and safety)
  - QualityAnalyzer (code quality with pylint, flake8, mypy)
  - TestAnalyzer (test coverage and quality analysis)
  - PerformanceAnalyzer (performance bottleneck detection)
- **Enhanced reporting system**:
  - Dual-format reports (Markdown and Text)
  - Project structure visualization with ASCII tree
  - Ignore markers (🚫) for filtered files
  - Comprehensive file statistics and metrics
  - Actionable recommendations and priority analysis
- **Modern CLI interface**:
  - `devix analyze` - Run comprehensive analysis
  - `devix config` - Manage configuration
  - `devix info` - Show package and analyzer information
- **`.devixignore` integration**:
  - GitIgnore-style pattern matching
  - Visual indicators in reports for ignored files
  - Configurable ignore patterns
- **Advanced Makefile with script reorganization**:
  - Organized scripts in `devix/scripts/` directory
  - UV package manager support with pip fallback
  - Docker containerization support
  - Watch mode for continuous analysis
  - Complete CI/CD pipeline simulation
- **PyPI publication pipeline**:
  - Comprehensive `pyproject.toml` configuration
  - Build system with hatchling
  - Multiple distribution formats (wheel, sdist)
  - Development, testing, and documentation dependencies

### Changed
- **Complete codebase restructure**: `devix/{core,analysis,reporting,cli,config}`
- **Parallel analyzer execution** for improved performance
- **Enhanced error handling** and logging throughout the system
- **Modernized configuration** using YAML and pyproject.toml standards
- **Improved package discovery** and module resolution

### Fixed
- **Makefile UV dependency** - added comprehensive pip/twine fallback
- **Project tree visualization** - collapsed folders with all ignored contents
- **Path resolution issues** in different execution contexts
- **Import resolution** for modular package structure
- **CLI command registration** and entry points

### Technical Details
- **Python compatibility**: 3.8+ with comprehensive testing
- **Zero breaking changes** for basic analysis workflows
- **Extensible architecture** for custom analyzers and formatters
- **Rich dependency management** with optional feature groups
- **Production-ready** with comprehensive error handling and logging

### Migration from AutoDev
- Legacy AutoDev workflows remain compatible
- Enhanced reports provide significantly more detail
- Modular architecture allows selective analyzer usage
- Configuration migrates automatically from legacy formats

### Performance Improvements
- **Parallel execution** of multiple analyzers
- **Efficient file filtering** with compiled ignore patterns
- **Optimized reporting** with lazy evaluation
- **Memory management** improvements for large codebases

## [1.x.x] - Legacy AutoDev Versions

Previous versions were part of the AutoDev system. See project history for details of legacy functionality that has been enhanced and modernized in Devix 2.0.0.

---

### Development Status

- **Status**: Production Ready
- **Stability**: Beta (API may change in minor versions)
- **Maintenance**: Actively maintained
- **Python Support**: 3.8, 3.9, 3.10, 3.11, 3.12

### Contributing

Please see [CONTRIBUTING.md](CONTRIBUTING.md) for guidelines on contributing to Devix.

### License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.
